@@ -995,12 +995,18 @@ PyAPI_FUNC(int) _PyComplex_AsCComplex(PyObject *arg0, struct Py_complex_t *arg1)
 PyAPI_FUNC(PyObject *) _PyComplex_FromCComplex(struct Py_complex_t *arg0);
 #define _PyDateTime_FromDateAndTime _PyPyDateTime_FromDateAndTime
 PyAPI_FUNC(PyObject *) _PyDateTime_FromDateAndTime(int arg0, int arg1, int arg2, int arg3, int arg4, int arg5, int arg6, PyObject *arg7, PyTypeObject *arg8);
+#define _PyDateTime_FromTimestamp _PyPyDateTime_FromTimestamp
+PyAPI_FUNC(PyObject *) _PyDateTime_FromTimestamp(PyObject *arg0, PyObject *arg1, PyObject *arg2);
 #define _PyDateTime_Import _PyPyDateTime_Import
 PyAPI_FUNC(PyDateTime_CAPI *) _PyDateTime_Import(void);
 #define _PyDate_FromDate _PyPyDate_FromDate
 PyAPI_FUNC(PyObject *) _PyDate_FromDate(int arg0, int arg1, int arg2, PyTypeObject *arg3);
+#define _PyDate_FromTimestamp _PyPyDate_FromTimestamp
+PyAPI_FUNC(PyObject *) _PyDate_FromTimestamp(PyObject *arg0, PyObject *arg1);
 #define _PyDelta_FromDelta _PyPyDelta_FromDelta
 PyAPI_FUNC(PyObject *) _PyDelta_FromDelta(int arg0, int arg1, int arg2, int arg3, PyTypeObject *arg4);
+#define _PyDict_GetItemWithError _PyPyDict_GetItemWithError
+PyAPI_FUNC(PyObject *) _PyDict_GetItemWithError(PyObject *arg0, PyObject *arg1);
 #define _PyEval_SliceIndex _PyPyEval_SliceIndex
 PyAPI_FUNC(int) _PyEval_SliceIndex(PyObject *arg0, Signed *arg1);
 #define _PyFloat_Unpack4 _PyPyFloat_Unpack4
